<?php

namespace Litecms\ButtonSetting\Providers;

use Illuminate\Support\ServiceProvider;

class ButtonSettingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'button_setting');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'button_setting');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.button_setting', function ($app) {
            return $this->app->make('Litecms\ButtonSetting\ButtonSetting');
        });

        // Bind ButtonSettings to repository
        $this->app->bind(
            'Litecms\ButtonSetting\Interfaces\ButtonSettingsRepositoryInterface',
            \Litecms\ButtonSetting\Repositories\Eloquent\ButtonSettingsRepository::class
        );        // Bind ButtonSettings to repository
        $this->app->bind(
            'Litecms\ButtonSetting\Interfaces\ButtonSettingsRepositoryInterface',
            \Litecms\ButtonSetting\Repositories\Eloquent\ButtonSettingsRepository::class
        );

        $this->app->register(\Litecms\ButtonSetting\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\ButtonSetting\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.button_setting'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/button_setting.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/button_setting')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/button_setting')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
